@@ -1,3 +1,4 @@
+#%% begin initialize phpPgAdmin-4.2.3-noname-P1
 ###################################################################
 export LANG=C
 
@@ -9,7 +10,8 @@ APACI_DIR=$ROOT/opt/httpd
 PHP_DIR=$ROOT/opt/php5
 
 ( cd $ROOT/opt/htdocs;
-  ln -sf  phpPgAdmin-4.2  phpPgAdmin;
+  rm -f phpPgAdmin;
+  ln -sf  phpPgAdmin-4.2.3  phpPgAdmin;
   /bin/su postgres -c 'psql -f phpPgAdmin/sql/reports-pgsql.sql';
 )
 
@@ -17,4 +19,7 @@ sed -e 's%usr/bin%opt/pgsql/bin%' \
     $ROOT/opt/htdocs/phpPgAdmin/conf/config.inc.php-dist \
     > $ROOT/opt/htdocs/phpPgAdmin/conf/config.inc.php
 
-/bin/chown -R wadm:apache $ROOT/opt/htdocs/phpPgAdmin-4.2
+/bin/chown -R wadm:apache $ROOT/opt/htdocs/phpPgAdmin-4.2.3
+
+/bin/su postgres -c '/opt/pgsql/bin/pg_passwd.sh www';
+#%% end
